# Author's Inscription

## ==Elvis.Shi==

- The problem with many projects is that they are directly given to users without any adaptation process, so I proposed the concept of `Free Coding`, which means free coding.
- After the program is running, all codes should be hot-updated, rather than the entire program going out of service if one place goes wrong
- Document management after the project is started is also very chaotic, and it is impossible to update in real time. The 0-1 of the project should be used by all participants and users as a whole

---

## Why do **Bomiot**

- Open source software should be a tool-like thing. Many open source software are made into application software
- This makes the user's learning cost very high and inconvenient to maintain
- As long as the underlying tools are well done, it can more conveniently get the functions that users want
- Through tools, more functions can be effectively expanded, which is what I think open source software should do

---

## Performance

- **Bomiot**'s underlying ASGI is written in **Rust**, so a certain performance is guaranteed
- You can use **locust** to perform performance testing on your own project
- Native also provides 3 test interfaces, FastAPI is the fastest, and Django is the slowest

---

## Signal

- **Bomiot** Signal mechanism, all documents and data are communicated in real time
- You can code freely without refreshing the server
- **Bomiot** creates a more friendly, free and convenient development and deployment environment